@@ -261,7 +261,7 @@ class Clip(NewReferenceObject):
         """
 
         t_start = 0
-        t1 = time.perf_counter()
+        #t1 = time.perf_counter()
         results = []
 
         for pattern in self.patterns:
@@ -275,8 +275,8 @@ class Clip(NewReferenceObject):
         # convert to events
         res = self._notes_to_events(results)
 
-        t2 = time.perf_counter()
-        print(t2-t1)
+        #t2 = time.perf_counter()
+        #print(t2-t1)
 
         return res
 
