@@ -18,17 +18,14 @@ NOTE_OFF = 0
 class Event(object):
 
 
-    __slots__ = [ 'type', 'note', 'time', 'on_event', 'scale', 'from_context' ]
+    __slots__ = [ 'type', 'note', 'time', 'on_event', 'from_context' ]
 
-    from . note import Note
-
-    def __init__(self, type=None, note=None, time=None, on_event=None, scale=None, from_context=None):
+    def __init__(self, type=None, note=None, time=None, on_event=None, from_context=None):
         self.type = type
         self.note = note
         self.time = time
         self.on_event = on_event
         self.from_context = from_context
-        self.scale = scale
 
     def __repr__(self):
         return "Event<Note=%s, type=%s, time=%s>" % (self.note, self.type, self.time)
@@ -39,5 +36,4 @@ class Event(object):
             note = self.note.copy(), # could be a Chord!  Be careful.
             time = self.time,
             on_event = self.on_event,
-            scale = self.scale, # is this used?
         )
