@@ -215,7 +215,8 @@ class Note(object):
         return n1
 
     def __repr__(self):
-        return "Note<%s|%s,len=%s,time=%s/%s,cc=%s,tie=%s,muted=%s,track_copy=%s>" % (
+        # FIXME: this will be simplified once we are doing less note debugging
+        return "Note<%s|%s,len=%s,time=%s/%s,cc=%s,tie=%s,muted=%s,track_copy=%s,def=%s>" % (
             self.name,
             self.octave,
             self.length,
@@ -224,6 +225,8 @@ class Note(object):
             self.ccs,
             self.tie,
             self.muted,
-            [x.name for x in self.track_copy])
+            [x.name for x in self.track_copy],
+            self.deferred_expressions
+        )
 
 
