@@ -16,7 +16,7 @@ from warpseq.model.slot import Slot
 class Pattern(NewReferenceObject, Directionable):
 
     __slots__ = [ 'name', 'slots', 'current_slots', 'octave_shift', 'rate', 'scale', 'direction', 'current_direction',
-                  'mod_expressions_callback', 'length', '_iterator', 'obj_id' ]
+                  'length', '_iterator', 'obj_id' ]
 
     SERIALIZER = Serializer(
         values = ( 'name', 'octave_shift', 'rate', 'scale', 'direction', 'length'),
@@ -27,13 +27,11 @@ class Pattern(NewReferenceObject, Directionable):
     )
 
     def __init__(self, name=None, slots=None, octave_shift=0, rate=1, scale=None, direction=FORWARD, length=None,
-                 mod_expressions_callback=None, obj_id=None):
+                 obj_id=None):
 
         self.name = name
         self.slots = slots
 
-
-
         self.octave_shift = octave_shift
         self.rate = rate
         self.scale = scale
@@ -41,13 +39,6 @@ class Pattern(NewReferenceObject, Directionable):
         for x in slots:
             assert isinstance(x, Slot)
 
-        if mod_expressions_callback:
-            # activate the generator
-            mod_expressions_callback = mod_expressions_callback()
-
-        self.mod_expressions_callback = mod_expressions_callback
-
-
         if length is None:
             length = len(slots)
 
