@@ -58,8 +58,6 @@ class RealtimeEngine(object):
 
         pattern = event.note.from_context.pattern
 
-        cb = pattern.mod_expressions_callback # this must be a generator
-
         if event.type == NOTE_ON:
 
             # we have to process deferred expressions twice because of the mod events
@@ -75,20 +73,6 @@ class RealtimeEngine(object):
                     return
                 event.note = value
 
-            # run mod expressions callback if attached
-            if cb is not None:
-                new_mod_expressions = next(cb)
-                for expr in new_mod_expressions:
-                    event.note = expr.evaluate(self.track, event.note)
-                    if event.note is None:
-                        return
-                    event.note = value
-
-                    # not entirely sure how this happens but we need to guard against it for now
-                    # this really should be part of "mod_expressions.do"
-                    if type(value) == Chord and len(value.notes) == 1:
-                        event.note = value.notes[0]
-
         # it is possible for mod expressions to take notes and return Chords. We have to do
         # cleanup here to turn this back into a list of notes.
 
